version 8.0
log using Figure2.log, replace
#delimit ;


*************************************************************;
*     File-Name:  Figure2.do                                *;
*     Date:       February 22, 2005                         *;
*     Author:     S.N. Golder                               *;
*     Purpose: get results for polarization, over range of  *;
*              values for effective threshold (Figure 2)    *;
*     Input File: pec_BJPS.dta                              *;
*     Output File: Figure2.log                              *;
*     Machine: Compaq                                       *;
*************************************************************;

use C:\data\pec_BJPS.dta;

set more off;


*************************************************************;
*                   Create some variables                   *;
*************************************************************;

gen coalitionseatlag = seatlag1 + seatlag2;

generate seatshare = coalitionseatlag*100;

generate seatshare_2 = seatshare*seatshare;

gen polarization_threshold = polarization*threshold;

gen asymmetry = seatlag1 /(seatlag1 + seatlag2);

replace asymmetry = 1-asymmetry if asymmetry<.5;

replace asymmetry = 2*(asymmetry - .5);

gen asym_seat =  asymmetry*seatshare;

*************************************************************;
*   Probit 2: Random effects probit, by election.           *;
*************************************************************;

xtprobit pec seatshare seatshare_2 incompatibility polarization threshold 
             polarization_threshold asymmetry asym_seat, re i (ident);


preserve;
drawnorm SN_b1-SN_b10, n(10000) means(e(b)) cov(e(V)) clear;

postutil clear;
postfile mypost prob_hat lo hi prob_hat1 lo1 hi1 diff_hat lod hid rel_risk lor hir
            using sim , replace;
            noisily display "start";

local a=0 ;
while `a' <= 35 { ;

quietly display "got here";
quietly {;

scalar h_seatshare=31.37;
scalar h_seatshare_2=(h_seatshare*h_seatshare);
scalar h_incompatibility= 24.41;
scalar h_polarization=28.58;
scalar h_threshold=8.59;
scalar h_asymmetry=.545;
scalar h_constant=1;

    generate x_betahat  = SN_b1*h_seatshare
                            + SN_b2*h_seatshare_2
                            + SN_b3*h_incompatibility
                            + SN_b4*h_polarization
                            + SN_b5*`a'
                            + SN_b6*h_polarization*`a'
                            + SN_b7*h_asymmetry
                            + SN_b8*h_asymmetry*h_seatshare
                            + SN_b9*h_constant;
    
    
    generate x_betahat1 = SN_b1*h_seatshare
                            + SN_b2*h_seatshare_2
                            + SN_b3*h_incompatibility
                            + SN_b4*(h_polarization+1)
                            + SN_b5*(`a')
                            + SN_b6*(h_polarization+1)*(`a')
                            + SN_b7*h_asymmetry
                            + SN_b8*h_asymmetry*h_seatshare
                            + SN_b9*h_constant;
    
    
    gen prob =norm(x_betahat);
    gen prob1=norm(x_betahat1);
    gen diff=prob1-prob;
    gen risk=prob1/prob;
    
    egen probhat =mean(prob);
    egen probhat1=mean(prob1);
    egen diffhat=mean(diff);
    egen relrisk=mean(risk);
    
    tempname prob_hat lo hi prob_hat1 lo1 hi1 diff_hat lod hid rel_risk lor hir;  

    _pctile prob, p(2.5,97.5) ;
    scalar `lo' = r(r1);
    scalar `hi' = r(r2);  
    
    _pctile prob1, p(2.5,97.5);
    scalar `lo1'= r(r1);
    scalar `hi1'= r(r2);  
    
    _pctile diff, p(2.5,97.5);
    scalar `lod'= r(r1);
    scalar `hid'= r(r2);  

    _pctile risk, p(2.5,97.5);
    scalar `lor'= r(r1);
    scalar `hir'= r(r2);  
    
    scalar `prob_hat'=probhat;
    scalar `prob_hat1'=probhat1;
    scalar `diff_hat'=diffhat;
    scalar `rel_risk'=relrisk;
    
    post mypost (`prob_hat') (`lo') (`hi') (`prob_hat1') (`lo1') (`hi1') 
                (`diff_hat') (`lod') (`hid') (`rel_risk') (`lor') (`hir') ;
    };      
    drop x_betahat x_betahat1 prob prob1 diff probhat probhat1 diffhat risk relrisk;
    local a=`a'+ 1 ;
    display "." _c;
} ;
display "";
postclose mypost;

use sim, clear;

gen threshold = _n-1;


graph twoway line diff_hat threshold, clwidth(medium) clcolor(blue) clcolor(black)
        ||   line lod threshold, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line hid threshold, clpattern(dash) clwidth(thin) clcolor(black)
        ||  ,   
            xlabel(0 5 10 15 20 25 30 35, labsize(3)) 
            ylabel(0 .001 .003 .005 .007, labsize(3))
            yscale(noline)
            xscale(noline)
            yline(0)
            yline(.001 .003 .005 .007, lcolor(white))
            legend(off)
            xtitle(Effective Threshold, size(3.5)  )
        xsca(titlegap(2))
        ysca(titlegap(2))
            ytitle("Marginal Effect of Polarization", size(3.5))
        scheme(s2mono) graphregion(fcolor(white));

graph export c:\data\Figure2.eps, replace;
translate @Graph c:\data\Figure2.wmf, replace;


*************************************************************;
*   Predicted probability always positive and significant.  *;
*   First differences (marginal effect of a one-unit change *;
*   in polarization) positive and significant if thresh>27. *;
*   This is obs 3957-4460, 11.29 percent.                   *;
*************************************************************;

*************************************************************;
*************************************************************;

log close;
