version 8.0
log using Figure4a.log, replace
#delimit ;


*************************************************************;
*     File-Name:  Figure4a.do                               *;
*     Date:       February 22, 2005                         *;
*     Author:     S.N. Golder                               *;
*     Purpose: effect of seatshare with asymmetry at one    *;
*              standard deviation below its mean (Figure 4a)*;
*     Input File: pec_BJPS.dta                              *;
*     Output File: Figure4a.log                             *;
*     Machine: Compaq                                       *;
*************************************************************;

use C:\data\pec_BJPS.dta;

set more off;


*************************************************************;
*                   Create some variables                   *;
*************************************************************;

gen coalitionseatlag = seatlag1 + seatlag2;

generate seatshare = coalitionseatlag*100;

generate seatshare_2 = seatshare*seatshare;

gen polarization_threshold = polarization*threshold;

gen asymmetry = seatlag1 /(seatlag1 + seatlag2);

replace asymmetry = 1-asymmetry if asymmetry<.5;

replace asymmetry = 2*(asymmetry - .5);

gen asym_seat =  asymmetry*seatshare;

*************************************************************;
*   Probit 2: Random effects probit, by election.           *;
*************************************************************;

xtprobit pec seatshare seatshare_2 incompatibility polarization threshold 
             polarization_threshold asymmetry asym_seat, re i (ident);

preserve;
drawnorm SN_b1-SN_b10, n(10000) means(e(b)) cov(e(V)) clear;

postutil clear;
postfile mypost prob_hat lo hi prob_hat1 lo1 hi1 diff_hat lod hid rel_risk lor hir
            using sim , replace;
            noisily display "start";

local a=0 ;
while `a' <= 101 { ;

quietly display "got here";
quietly {;


scalar h_incompatibility= 24.41;
scalar h_polarization=28.58;
scalar h_threshold=8.59;
scalar h_polarization_threshold=(h_polarization*h_threshold);
scalar h_asymmetry=.235;
scalar h_constant=1;


    generate x_betahat  = SN_b1*`a' + SN_b2*`a'*`a'
                            + SN_b3*h_incompatibility
                            + SN_b4*h_polarization
                            + SN_b5*h_threshold
                            + SN_b6*h_polarization_threshold
                            + SN_b7*h_asymmetry
                            + SN_b8*h_asymmetry*`a'
                            + SN_b9*h_constant;
    
    
    generate x_betahat1  = SN_b1*(`a'+1) + SN_b2*(`a'+1)*(`a'+1)
                            + SN_b3*h_incompatibility
                            + SN_b4*h_polarization
                            + SN_b5*h_threshold
                            + SN_b6*h_polarization_threshold
                            + SN_b7*h_asymmetry
                            + SN_b8*h_asymmetry*(`a'+1)
                            + SN_b9*h_constant;
    
    
    gen prob =norm(x_betahat);
    gen prob1=norm(x_betahat1);
    gen diff=prob1-prob;
    gen risk=prob1/prob;
    
    egen probhat =mean(prob);
    egen probhat1=mean(prob1);
    egen diffhat=mean(diff);
    egen relrisk=mean(risk);
    
    tempname prob_hat lo hi prob_hat1 lo1 hi1 diff_hat lod hid rel_risk lor hir;  

    _pctile prob, p(2.5,97.5) ;
    scalar `lo' = r(r1);
    scalar `hi' = r(r2);  
    
    _pctile prob1, p(2.5,97.5);
    scalar `lo1'= r(r1);
    scalar `hi1'= r(r2);  
    
    _pctile diff, p(2.5,97.5);
    scalar `lod'= r(r1);
    scalar `hid'= r(r2);  

    _pctile risk, p(2.5,97.5);
    scalar `lor'= r(r1);
    scalar `hir'= r(r2);  
    
    scalar `prob_hat'=probhat;
    scalar `prob_hat1'=probhat1;
    scalar `diff_hat'=diffhat;
    scalar `rel_risk'=relrisk;
    
    post mypost (`prob_hat') (`lo') (`hi') (`prob_hat1') (`lo1') (`hi1') 
                (`diff_hat') (`lod') (`hid') (`rel_risk') (`lor') (`hir') ;
    };      
    drop x_betahat x_betahat1 prob prob1 diff probhat probhat1 diffhat risk relrisk;
    local a=`a'+ 1 ;
    display "." _c;
} ;
display "";
postclose mypost;

use sim, clear;

gen seatshare = _n-1;

graph twoway line diff_hat seatshare, clwidth(medium) clcolor(blue) clcolor(black)
        ||   line lod seatshare, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line hid seatshare, clpattern(dash) clwidth(thin) clcolor(black)
        ||  ,   
            xlabel(0 10 20 30 40 50 60 70 80 90 100, labsize(4)) 
            ylabel(-.003 -.002 -.001 0 .001 .002 .003, labsize(4))
            yscale(noline)
            xscale(noline)
            yline(0)
            yline(-.003 -.002 -.001 .001 .002 .003, lcolor(white))
            legend(off)
        xsca(titlegap(2))
        ysca(titlegap(2))
        scheme(s2mono) graphregion(fcolor(white));


graph export c:\data\Figure4a.eps, replace;
translate @Graph c:\data\Figure4a.wmf, replace;

*************************************************************;
*  prob_hat always positive and significant.                *;
*  Marginal effect, diff_hat, positive and significant when *;
*  seatshare<34. This is observations 1-2118, or 47.49      *;
*  percent of the sample. The marginal effect is negative   *;
*  and significant if seatshare>44. This is observations    *;
*  2640-4460, or 40.83 percent.  In total, the marginal     *;
*  effect is significant for 88.32 percent of the sample.   *;
*************************************************************;

*************************************************************;
*************************************************************;

log close;
